package com.ruoyi.project.approval.service.impl;

import com.ruoyi.project.approval.domain.TApproval;
import com.ruoyi.project.approval.mapper.TApprovalMapper;
import com.ruoyi.project.approval.service.ITApprovalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 批文清单Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-03-25
 */
@Service
public class TApprovalServiceImpl implements ITApprovalService 
{
    @Autowired
    private TApprovalMapper tApprovalMapper;

    /**
     * 查询批文清单
     * 
     * @param id 批文清单主键
     * @return 批文清单
     */
    @Override
    public TApproval selectTApprovalById(Long id)
    {
        return tApprovalMapper.selectTApprovalById(id);
    }

    /**
     * 查询批文清单列表
     * 
     * @param tApproval 批文清单
     * @return 批文清单
     */
    @Override
    public List<TApproval> selectTApprovalList(TApproval tApproval)
    {
        return tApprovalMapper.selectTApprovalList(tApproval);
    }

    /**
     * 新增批文清单
     * 
     * @param tApproval 批文清单
     * @return 结果
     */
    @Override
    public int insertTApproval(TApproval tApproval)
    {
        return tApprovalMapper.insertTApproval(tApproval);
    }

    /**
     * 修改批文清单
     * 
     * @param tApproval 批文清单
     * @return 结果
     */
    @Override
    public int updateTApproval(TApproval tApproval)
    {
        return tApprovalMapper.updateTApproval(tApproval);
    }

    /**
     * 批量删除批文清单
     * 
     * @param ids 需要删除的批文清单主键
     * @return 结果
     */
    @Override
    public int deleteTApprovalByIds(Long[] ids)
    {
        return tApprovalMapper.deleteTApprovalByIds(ids);
    }

    /**
     * 删除批文清单信息
     * 
     * @param id 批文清单主键
     * @return 结果
     */
    @Override
    public int deleteTApprovalById(Long id)
    {
        return tApprovalMapper.deleteTApprovalById(id);
    }
}
